@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -350,6 +350,7 @@ void db_connect(int type, MYSQL *mysql) {
 		free(hostname);
 	}
 
+    #ifdef HAS_MYSQL_OPT_SSL_KEY
 	if (ssl_key != NULL) {
 		free(ssl_key);
 	}
@@ -361,6 +362,7 @@ void db_connect(int type, MYSQL *mysql) {
 	if (ssl_cert != NULL) {
 		free(ssl_cert);
 	}
+    #endif
 
 	if (!success){
 		printf("FATAL: Connection Failed, Error:'%i', Message:'%s'\n", error, mysql_error(mysql));
