@@ -1558,9 +1558,12 @@ int is_hexadecimal(const char * str, const short ignore_special) {
  */
 char *strip_alpha(char *string) {
 	int i;
+	int j;
 
 	i = strlen(string);
+	j = 0;
 
+	/* trim trailing characters */
 	while (i >= 0) {
 		if (isdigit((int)string[i])) {
 			break;
@@ -1570,6 +1573,21 @@ char *strip_alpha(char *string) {
 		i--;
 	}
 
+	/* trim leading characters */
+	while (j < i) {
+		if (isdigit((int)string[j])) {
+			break;
+		} else if (string[j] == '-') {
+			break;
+		} else if (string[j] == '+') {
+			j++;
+		} else {
+			j++;
+		}
+	}
+
+	string = &string[j];
+
 	return string;
 }
 
@@ -1635,7 +1653,9 @@ char *add_slashes(char *string) {
  *
 */
 #pragma GCC diagnostic push
+#if (defined(__GNUC__) && (__GNUC__ > 7)) || (__GNUC__ == 7 && defined(__GNUC_MINOR__) && __GNUC_MINOR__ > 1)
 #pragma GCC diagnostic ignored "-Wstringop-overflow"
+#endif
 char *strncopy(char *dst, const char *src, size_t obuf) {
 	assert(dst != 0);
 	assert(src != 0);
